This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] Clean up config/sparc/pbd.h comments


I deleted a few target-independent comments,
deleted a really misleading comment, and rewrote "GNU CC" and "GNU compiler"
as "GCC".  I also tightened a couple of comments by removing a few blank lines
and some dead comment space.

	* config/sparc/pbd.h: Clean up comments.

Index: pbd.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/sparc/pbd.h,v
retrieving revision 1.14
diff -u -r1.14 pbd.h
--- pbd.h	17 May 2003 07:19:56 -0000	1.14
+++ pbd.h	17 Jun 2003 01:26:29 -0000
@@ -1,21 +1,21 @@
 /* Definitions of target machine for GNU compiler, Citicorp/TTI Unicom PBD
    version (using GAS and COFF (encapsulated is unacceptable) )
    Copyright (C) 1990, 1996, 2000 Free Software Foundation, Inc.
 
-This file is part of GNU CC.
+This file is part of GCC.
 
-GNU CC is free software; you can redistribute it and/or modify
+GCC is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.
 
-GNU CC is distributed in the hope that it will be useful,
+GCC is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU CC; see the file COPYING.  If not, write to
+along with GCC; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
 Boston, MA 02111-1307, USA.  */
 
@@ -30,15 +30,11 @@
   while (0)
 
 /* We want DBX format for use with gdb under COFF.  */
-
 #define DBX_DEBUGGING_INFO 1
 
-/* Generate calls to memcpy, memcmp and memset.  */
-
 #define TARGET_MEM_FUNCTIONS
 
 /* we use /lib/libp/lib*  when profiling */
-
 #undef LIB_SPEC
 #define LIB_SPEC "%{p:-L/usr/lib/libp} %{pg:-L/usr/lib/libp} -lc"
 
@@ -54,7 +50,7 @@
  * Finally, we must explicitly specify the file from libgcc.a that defines
  * exit(), otherwise if the user specifies (for example) "-lc_s" on the 
  * command line, the wrong exit() will be used and global destructors will 
- * not get called .
+ * not get called.
  */
 
 #define STARTFILE_SPEC \
@@ -101,16 +97,10 @@
   }
  */
 
-/* The prefix to add to user-visible assembler symbols.  */
-
 #undef USER_LABEL_PREFIX
 #define USER_LABEL_PREFIX ""
 
-/* fixes: */
-/*
- *  Internal labels are prefixed with a period.
- */
-
+/*  Internal labels are prefixed with a period. */
 #undef  LOCAL_LABEL_PREFIX
 #define LOCAL_LABEL_PREFIX  "."
 
@@ -123,15 +113,9 @@
 #define ASM_GENERATE_INTERNAL_LABEL(LABEL,PREFIX,NUM)                   \
         sprintf (LABEL, "*.%s%ld", PREFIX, (long)(NUM))
 
-/* This is how to output an element of a case-vector that is relative.  */
-
 #undef  ASM_OUTPUT_ADDR_DIFF_ELT
 #define ASM_OUTPUT_ADDR_DIFF_ELT(FILE, BODY, VALUE, REL)  \
   fprintf (FILE, "\t.word .L%d-.L%d\n", VALUE, REL)
-
-/* This is how to output an element of a case-vector that is absolute.
-   (The 68000 does not use such vectors,
-   but we must define this macro anyway.)  */
 
 #undef ASM_OUTPUT_ADDR_VEC_ELT
 #define ASM_OUTPUT_ADDR_VEC_ELT(FILE, VALUE)  \
@@ -1,21 +1,21 @@
-/* Definitions of target machine for GNU compiler, Citicorp/TTI Unicom PBD
+/* Definitions of target machine for GCC, Citicorp/TTI Unicom PBD
    version (using GAS and COFF (encapsulated is unacceptable) )
    Copyright (C) 1990, 1996, 2000 Free Software Foundation, Inc.

-- 
Nathanael Nerode  <neroden at gcc.gnu.org>
Don't use the GNU FDL for free documentation.  See
<http://home.twcny.rr.com/nerode/neroden/fdl.html>


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]